@@ -5,6 +5,4 @@ Created on Mon Jun  6 16:52:58 2022
 @author: CA013877
 """
 
-from advanced_analytics.features import (
-    saying_hello_features
-    )
\ No newline at end of file
+__all__ = [saying_hello_features]
\ No newline at end of file
